@@ -517,7 +517,7 @@ class RibbonFrame(wx.Frame):
 
         data = gallery.GetItemClientData(item)
 
-        if name != None:
+        if name is not None:
             name = data.GetName()
 
         return data.GetColour(), name
@@ -531,7 +531,7 @@ class RibbonFrame(wx.Frame):
         gallery = event.GetGallery()
         provider = gallery.GetArtProvider()
 
-        if event.GetGalleryItem() != None:
+        if event.GetGalleryItem() is not None:
             if provider == self._ribbon.GetArtProvider():
                 provider = provider.Clone()
                 gallery.SetArtProvider(provider)
@@ -799,7 +799,7 @@ class RibbonFrame(wx.Frame):
                                        (c.Blue() + 192) % 256)
 
             dc.SetTextForeground(foreground)
-            dc.DrawText(colour, (iWidth - size.GetWidth() + 1) / 2, (iHeight - size.GetHeight()) / 2)
+            dc.DrawText(colour, (iWidth - size.GetWidth() + 1) // 2, (iHeight - size.GetHeight()) // 2)
             dc.SelectObjectAsSource(wx.NullBitmap)
 
             item = gallery.Append(bitmap, wx.ID_ANY)
@@ -835,7 +835,7 @@ class RibbonFrame(wx.Frame):
                     item = None
 
             # Colour not in gallery - add it
-            if item == None:
+            if item is None:
                 item = self.AddColourToGallery(gallery, clr.GetAsString(wx.C2S_HTML_SYNTAX), self._bitmap_creation_dc,
                                                clr)
                 gallery.Realize()
