@@ -5,7 +5,7 @@
 #
 # Created:     10-Sept-2011
 # Copyright:   (c) 2011 by Kevin Ollivier
-# Copyright:   (c) 2011-2018 by Total Control Software
+# Copyright:   (c) 2011-2020 by Total Control Software
 # License:     wxWindows License
 #---------------------------------------------------------------------------
 
@@ -35,6 +35,7 @@ ITEMS  = [
             'wxDataViewCustomRenderer',
             'wxDataViewTextRenderer',
             'wxDataViewIconTextRenderer',
+            'wxDataViewCheckIconTextRenderer',
             'wxDataViewProgressRenderer',
             'wxDataViewSpinRenderer',
             'wxDataViewToggleRenderer',
@@ -46,6 +47,7 @@ ITEMS  = [
             'wxDataViewColumn',
             'wxDataViewCtrl',
             'wxDataViewEvent',
+            'wxDataViewValueAdjuster',
 
             'wxDataViewListCtrl',
             'wxDataViewListStore',
@@ -80,7 +82,7 @@ def run():
 
     c.addCppMethod('int', '__nonzero__', '()', "return self->IsOk();")
     c.addCppMethod('int', '__bool__', '()', "return self->IsOk();")
-    c.addCppMethod('long', '__hash__', '()', "return (long)self->GetID();")
+    c.addCppMethod('long', '__hash__', '()', "return (long)(intptr_t)self->GetID();")
 
     c.addCppMethod('bool', '__eq__', '(wxDataViewItem* other)',
                    "return other ? (self->GetID() == other->GetID()) : false;")
@@ -107,7 +109,7 @@ def run():
     # Change the GetValue method to return the value instead of passing it
     # through a parameter for modification.
     c.find('GetValue.variant').out = True
-
+    c.find('GetValue').cppSignature = 'void (wxVariant& variant, const wxDataViewItem& item, unsigned int col)'
 
     # The DataViewItemObjectMapper class helps map from data items to Python
     # objects, and is used as a base class of PyDataViewModel as a
@@ -123,7 +125,7 @@ def run():
 
             By default a regular dictionary is used to implement the ID to object
             mapping. Optionally a WeakValueDictionary can be useful when there will be
-            a high turnover of objects and mantaining an extra reference to the
+            a high turnover of objects and maintaining an extra reference to the
             objects would be unwise.  If weak references are used then the objects
             associated with data items must be weak-referenceable.  (Things like
             stock lists and dictionaries are not.)  See :meth:`UseWeakRefs`.
@@ -193,6 +195,7 @@ def run():
     # Change the GetValueByRow method to return the value instead of passing
     # it through a parameter for modification.
     c.find('GetValueByRow.variant').out = True
+    c.find('GetValueByRow').cppSignature = 'void (wxVariant& variant, unsigned int row, unsigned int col)'
 
     # declare implementations for base class virtuals
     c.addItem(etgtools.WigCode("""\
@@ -234,13 +237,21 @@ def run():
         method.find('value').type = 'wxDVCVariant&'
         method.cppSignature = sig
 
+    def _fixupTypeParam(klass):
+        param = klass.findItem('{}.varianttype'.format(klass.name))
+        if param and param.default == 'GetDefaultType()':
+            param.default = '{}::GetDefaultType()'.format(klass.name)
 
     c = module.find('wxDataViewRenderer')
     c.addPrivateCopyCtor()
     c.abstract = True
-    c.addAutoProperties()
     c.find('GetView').ignore(False)
 
+    # TODO: This is only available when wxUSE_ACCESSIBILITY is set to 1
+    c.find('GetAccessibleDescription').ignore()
+
+    c.addAutoProperties()
+
     # Change variant getters to return the value
     for name, sig in [
         ('GetValue',               'bool (wxVariant& value)'),
@@ -260,6 +271,7 @@ def run():
 
 
     c = module.find('wxDataViewCustomRenderer')
+    _fixupTypeParam(c)
     m = c.find('GetValueFromEditorCtrl')
     _fixupBoolGetters(m, 'bool (wxWindow * editor, wxVariant& value)')
 
@@ -306,6 +318,7 @@ def run():
                   ]:
         c = module.find(name)
         c.addAutoProperties()
+        _fixupTypeParam(c)
 
         c.addItem(etgtools.WigCode("""\
             virtual bool SetValue( const wxDVCVariant &value ) [bool (const wxVariant& value)];
@@ -313,7 +326,6 @@ def run():
             %Property(name=Value, get=GetValue, set=SetValue)
             """, protection='public'))
 
-
     # The SpinRenderer has a few additional pure virtuals that need to be declared
     # since it derives from DataViewCustomRenderer
     c = module.find('wxDataViewSpinRenderer')
@@ -332,7 +344,7 @@ def run():
     c.addItem(etgtools.WigCode("""\
         virtual void SetTitle(const wxString& title);
         virtual wxString GetTitle() const;
-        virtual void SetBitmap(const wxBitmap& bitmap);
+        virtual void SetBitmap(const wxBitmapBundle& bitmap);
         virtual wxBitmap GetBitmap() const;
         virtual void SetWidth(int width);
         virtual int GetWidth() const;
@@ -368,6 +380,8 @@ def run():
     tools.fixWindowClass(c)
     module.addGlobalStr('wxDataViewCtrlNameStr', c)
 
+    tools.addEnableSystemTheme(c, 'wx.dataview.DataViewCtrl')
+
     c.find('AssociateModel.model').transfer = True
     c.find('AssociateModel').pyName = '_AssociateModel'
     c.addPyMethod('AssociateModel', '(self, model)',
@@ -437,12 +451,14 @@ def run():
             """)
 
 
+    # TODO: add support for wxVector templates
+    c.find('GetSortingColumns').ignore()
+
+
     #-----------------------------------------------------------------
     c = module.find('wxDataViewEvent')
     tools.fixEventClass(c)
 
-    c.addProperty('EditCancelled', 'IsEditCancelled', 'SetEditCanceled')
-
     c.find('SetCache.from').name = 'from_'
     c.find('SetCache.to').name = 'to_'
 
@@ -524,6 +540,8 @@ def run():
     c.find('PrependItem.values').type = 'const wxVariantVector&'
     c.find('InsertItem.values').type = 'const wxVariantVector&'
     c.find('GetValueByRow.value').out = True
+    c.find('GetValueByRow').cppSignature = 'void (wxVariant& value, unsigned int row, unsigned int col)'
+
     c.addAutoProperties()
 
 
