@@ -35,7 +35,8 @@ public:
     Basic property with string value.
 
     <b>Supported special attributes:</b>
-    - "Password": set to 1 in order to enable wxTE_PASSWORD on the editor.
+    - ::wxPG_STRING_PASSWORD: set to @true in order to enable ::wxTE_PASSWORD
+    on the editor.
 
     @remarks
     - If value "<composed>" is set, then actual value is formed (or composed)
@@ -99,6 +100,67 @@ public:
     virtual bool Validate(wxWindow* parent);
 };
 
+/** @class wxNumericProperty
+    @ingroup classes
+
+    This is an abstract class which serves as a base class for numeric properties,
+    like wxIntProperty, wxUIntProperty, wxFloatProperty.
+
+    <b>Supported special attributes:</b>
+    - ::wxPG_ATTR_MIN, ::wxPG_ATTR_MAX: Specify acceptable value range.
+    - ::wxPG_ATTR_SPINCTRL_STEP: How much number changes when SpinCtrl editor
+    button is pressed (or up/down on keyboard).
+    - ::wxPG_ATTR_SPINCTRL_WRAP: Specify if value modified with SpinCtrl editor
+    wraps at Min/Max.
+    - ::wxPG_ATTR_SPINCTRL_MOTION: Specify if value can also by changed with
+    SpinCtrl editor by moving mouse when left mouse button is being pressed.
+
+    @since 3.1.3
+*/
+class wxNumericProperty : public wxPGProperty
+{
+public:
+    virtual ~wxNumericProperty();
+
+    virtual bool DoSetAttribute(const wxString& name, wxVariant& value);
+
+    /**
+        Returns what would be the new value of the property after adding
+        SpinCtrl editor step to the current value. Current value range
+        and wrapping (if enabled) are taken into account.
+        This member has to be implemented in derived properties.
+
+        @param stepScale
+        SpinCtrl editor step is first multiplied by this factor and next
+        added to the current value.
+
+        @return
+        Value which property would have after adding SpinCtrl editor step.
+
+        @remark
+        Current property value is not changed.
+    */
+    virtual wxVariant AddSpinStepValue(long stepScale) const = 0;
+
+    /**
+        Return @true if value can be changed with SpinCtrl editor by moving
+        the mouse.
+    */
+    bool UseSpinMotion() const;
+
+protected:
+    /**
+        Constructor is protected because wxNumericProperty is only a base
+        class for other numeric property classes.
+    */
+    wxNumericProperty(const wxString& label, const wxString& name);
+
+    wxVariant m_minVal;
+    wxVariant m_maxVal;
+    bool      m_spinMotion;
+    wxVariant m_spinStep;
+    bool      m_spinWrap;
+};
 
 
 /** @class wxIntProperty
@@ -140,9 +202,11 @@ public:
 
 
     <b>Supported special attributes:</b>
-    - "Min", "Max": Specify acceptable value range.
+    - ::wxPG_ATTR_MIN, ::wxPG_ATTR_MAX, ::wxPG_ATTR_SPINCTRL_STEP,
+    ::wxPG_ATTR_SPINCTRL_WRAP, ::wxPG_ATTR_SPINCTRL_MOTION:
+    like in wxNumericProperty.
 */
-class wxIntProperty : public wxPGProperty
+class wxIntProperty : public wxNumericProperty
 {
 public:
     wxIntProperty( const wxString& label = wxPG_LABEL,
@@ -164,14 +228,7 @@ public:
                              int argFlags = 0 ) const;
     static wxValidator* GetClassValidator();
     virtual wxValidator* DoGetValidator() const;
-
-    /** Validation helper.
-    */
-    static bool DoValidation( const wxPGProperty* property,
-                              wxLongLong_t& value,
-                              wxPGValidationInfo* pValidationInfo,
-                              int mode =
-                                wxPG_PROPERTY_VALIDATION_ERROR_MESSAGE );
+    virtual wxVariant AddSpinStepValue(long stepScale) const;
 };
 
 
@@ -181,19 +238,21 @@ public:
     Seamlessly supports 64-bit integer (wxULongLong) on overflow.
 
     <b>Supported special attributes:</b>
-    - "Min", "Max": Specify acceptable value range.
-    - "Base": Define base. Valid constants are wxPG_BASE_OCT, wxPG_BASE_DEC,
-    wxPG_BASE_HEX and wxPG_BASE_HEXL (lowercase characters). Arbitrary bases
-    are <b>not</b> supported.
-    - "Prefix": Possible values are wxPG_PREFIX_NONE, wxPG_PREFIX_0x, and
-    wxPG_PREFIX_DOLLAR_SIGN. Only wxPG_PREFIX_NONE works with Decimal and Octal
-    numbers.
+    - ::wxPG_UINT_BASE: Define base. Valid constants are ::wxPG_BASE_OCT,
+    ::wxPG_BASE_DEC, ::wxPG_BASE_HEX and ::wxPG_BASE_HEXL (lowercase characters).
+    Arbitrary bases are <b>not</b> supported.
+    - ::wxPG_UINT_PREFIX: Possible values are ::wxPG_PREFIX_NONE, ::wxPG_PREFIX_0x,
+    and ::wxPG_PREFIX_DOLLAR_SIGN. Only ::wxPG_PREFIX_NONE works with Decimal
+    and Octal numbers.
+    - ::wxPG_ATTR_MIN, ::wxPG_ATTR_MAX, ::wxPG_ATTR_SPINCTRL_STEP,
+    ::wxPG_ATTR_SPINCTRL_WRAP, ::wxPG_ATTR_SPINCTRL_MOTION:
+    like in wxNumericProperty.
 
     @remarks
     - For example how to use seamless 64-bit integer support, see wxIntProperty
     documentation (just use wxULongLong instead of wxLongLong).
 */
-class wxUIntProperty : public wxPGProperty
+class wxUIntProperty : public wxNumericProperty
 {
 public:
     wxUIntProperty( const wxString& label = wxPG_LABEL,
@@ -214,6 +273,8 @@ public:
     virtual bool IntToValue( wxVariant& variant,
                              int number,
                              int argFlags = 0 ) const;
+    virtual wxVariant AddSpinStepValue(long stepScale) const;
+
 protected:
     wxByte      m_base;
     wxByte      m_realBase; // translated to 8,16,etc.
@@ -226,10 +287,13 @@ protected:
     Basic property with double-precision floating point value.
 
     <b>Supported special attributes:</b>
-    - "Precision": Sets the (max) precision used when floating point value is
-    rendered as text. The default -1 means infinite precision.
+    - ::wxPG_FLOAT_PRECISION: Sets the (max) precision used when floating point
+    value is rendered as text. The default -1 means infinite precision.
+    - ::wxPG_ATTR_MIN, ::wxPG_ATTR_MAX, ::wxPG_ATTR_SPINCTRL_STEP,
+    ::wxPG_ATTR_SPINCTRL_WRAP, ::wxPG_ATTR_SPINCTRL_MOTION:
+    like in wxNumericProperty.
 */
-class wxFloatProperty : public wxPGProperty
+class wxFloatProperty : public wxNumericProperty
 {
 public:
     wxFloatProperty( const wxString& label = wxPG_LABEL,
@@ -242,19 +306,12 @@ public:
                                 const wxString& text,
                                 int argFlags = 0 ) const;
     virtual bool DoSetAttribute( const wxString& name, wxVariant& value );
-    virtual wxVariant DoGetAttribute( const wxString& name ) const;
     virtual bool ValidateValue( wxVariant& value,
                                 wxPGValidationInfo& validationInfo ) const;
 
-    /** Validation helper.
-    */
-    static bool DoValidation( const wxPGProperty* property,
-                              double& value,
-                              wxPGValidationInfo* pValidationInfo,
-                              int mode =
-                                 wxPG_PROPERTY_VALIDATION_ERROR_MESSAGE );
     static wxValidator* GetClassValidator();
     virtual wxValidator* DoGetValidator () const;
+    virtual wxVariant AddSpinStepValue(long stepScale) const;
 
 protected:
     int m_precision;
@@ -267,8 +324,10 @@ protected:
     Basic property with boolean value.
 
     <b>Supported special attributes:</b>
-    - "UseCheckbox": Set to 1 to use check box editor instead of combo box.
-    - "UseDClickCycling": Set to 1 to cycle combo box instead showing the list.
+    - ::wxPG_BOOL_USE_CHECKBOX: Set to @true to use check box editor instead
+    of combo box.
+    - ::wxPG_BOOL_USE_DOUBLE_CLICK_CYCLING: Set to @true to cycle combo box
+    instead showing the list.
 */
 class wxBoolProperty : public wxPGProperty
 {
@@ -312,7 +371,7 @@ public:
                     const wxChar* const* labels = NULL,
                     const long* values = NULL,
                     int value = 0 );
-    
+
     wxEnumProperty( const wxString& label,
                     const wxString& name,
                     wxPGChoices& choices,
@@ -361,8 +420,6 @@ public:
     // this take advantage of it.
     virtual int GetChoiceSelection() const;
 
-    virtual void OnValidationFailure( wxVariant& pendingValue );
-
 protected:
 
     int GetIndex() const;
@@ -384,7 +441,7 @@ protected:
     wxEnumProperty with wxString value and writable combo box editor.
 
     @remarks
-    Uses int value, similar to wxEnumProperty, unless text entered by user is
+    Uses int value, similar to wxEnumProperty, unless text entered by user
     is not in choices (in which case string value is used).
 */
 class wxEditEnumProperty : public wxEnumProperty
@@ -489,20 +546,56 @@ protected:
 };
 
 
-
-/** @class wxPGFileDialogAdapter
+/** @class wxEditorDialogProperty
     @ingroup classes
+
+    This is an abstract class which serves as a base class for the properties
+    having a button triggering an editor dialog, like e.g. wxLongStringProperty,
+    wxDirProperty, wxFileProperty.
+
+    <b>Supported special attributes:</b>
+    - ::wxPG_DIALOG_TITLE: Sets a specific title for the editor dialog.
+
+    @since 3.1.3
 */
-class wxPGFileDialogAdapter : public wxPGEditorDialogAdapter
+class wxEditorDialogProperty : public wxPGProperty
 {
 public:
-    virtual bool DoShowDialog( wxPropertyGrid* propGrid,
-                               wxPGProperty* property );
+    virtual ~wxEditorDialogProperty();
+
+    virtual wxPGEditorDialogAdapter* GetEditorDialog() const;
+    virtual bool DoSetAttribute( const wxString& name, wxVariant& value );
+
+protected:
+    /**
+        Constructor is protected because wxEditorDialogProperty is only
+        the base class for other property classes.
+    */
+    wxEditorDialogProperty(const wxString& label, const wxString& name);
+
+    /**
+        Shows editor dialog. Value to be edited should be read from
+        @a value, and if dialog is not cancelled, it should be stored back
+        and @true should be returned.
+
+        @param value
+        Value to be edited.
+
+        @param pg
+        Property grid in which property is displayed.
+
+        @return
+        Returns @true if editor dialog was not cancelled and @a value
+        was updated.
+    */
+    virtual bool DisplayEditorDialog(wxPropertyGrid* pg, wxVariant& value) = 0;
+
+    wxString  m_dlgTitle;
+    long      m_dlgStyle;
 };
 
 
-
-// Indicates first bit useable by derived properties.
+// Indicates first bit usable by derived properties.
 #define wxPG_PROP_SHOW_FULL_FILENAME  wxPG_PROP_CLASS_SPECIFIC_1
 
 /** @class wxFileProperty
@@ -510,16 +603,18 @@ public:
     Like wxLongStringProperty, but the button triggers file selector instead.
 
     <b>Supported special attributes:</b>
-    - "Wildcard": Sets wildcard (see wxFileDialog for format details), "All
-    files..." is default.
-    - "ShowFullPath": Default 1. When 0, only the file name is shown (i.e. drive
-      and directory are hidden).
-    - "ShowRelativePath": If set, then the filename is shown relative to the
-    given path string.
-    - "InitialPath": Sets the initial path of where to look for files.
-    - "DialogTitle": Sets a specific title for the dir dialog.
+    - ::wxPG_DIALOG_TITLE: Sets a specific title for the file dialog (since 3.1.3).
+    - ::wxPG_FILE_DIALOG_STYLE: Sets a specific wxFileDialog style for the file
+    dialog (since 2.9.4).
+    - ::wxPG_FILE_WILDCARD: Sets wildcard (see wxFileDialog for format details),
+    "All files..." is default.
+    - ::wxPG_FILE_SHOW_FULL_PATH: Default @true. When @false, only the file name is
+    shown (i.e. drive and directory are hidden).
+    - ::wxPG_FILE_SHOW_RELATIVE_PATH: If set, then the filename is shown relative
+    to the given path string.
+    - ::wxPG_FILE_INITIAL_PATH: Sets the initial path of where to look for files.
 */
-class wxFileProperty : public wxPGProperty
+class wxFileProperty : public wxEditorDialogProperty
 {
 public:
 
@@ -533,7 +628,6 @@ public:
     virtual bool StringToValue( wxVariant& variant,
                                 const wxString& text,
                                 int argFlags = 0 ) const;
-    virtual wxPGEditorDialogAdapter* GetEditorDialog() const;
     virtual bool DoSetAttribute( const wxString& name, wxVariant& value );
 
     static wxValidator* GetClassValidator();
@@ -545,34 +639,26 @@ public:
     wxFileName GetFileName() const;
 
 protected:
+    virtual bool DisplayEditorDialog(wxPropertyGrid* pg, wxVariant& value);
+
     wxString    m_wildcard;
-    wxString    m_basePath; // If set, then show path relative to it
-    wxString    m_initialPath; // If set, start the file dialog here
-    wxString    m_dlgTitle; // If set, used as title for file dialog
-    int         m_indFilter; // index to the selected filter
+    wxString    m_basePath;
+    wxString    m_initialPath;
+    int         m_indFilter;
 };
 
 
-
-#define wxPG_PROP_NO_ESCAPE     wxPG_PROP_CLASS_SPECIFIC_1
-
-/** @class wxPGLongStringDialogAdapter
-    @ingroup classes
-*/
-class wxPGLongStringDialogAdapter : public wxPGEditorDialogAdapter
-{
-public:
-    virtual bool DoShowDialog( wxPropertyGrid* propGrid,
-                               wxPGProperty* property );
-};
-
+#define wxPG_PROP_ACTIVE_BTN    wxPG_PROP_CLASS_SPECIFIC_1
 
 /** @class wxLongStringProperty
     @ingroup classes
     Like wxStringProperty, but has a button that triggers a small text
     editor dialog.
+
+    <b>Supported special attributes:</b>
+    - ::wxPG_DIALOG_TITLE: Sets a specific title for the text editor dialog (since 3.1.3).
 */
-class wxLongStringProperty : public wxPGProperty
+class wxLongStringProperty : public wxEditorDialogProperty
 {
 public:
 
@@ -585,44 +671,35 @@ public:
     virtual bool StringToValue( wxVariant& variant,
                                 const wxString& text,
                                 int argFlags = 0 ) const;
-    virtual bool OnEvent( wxPropertyGrid* propgrid,
-                          wxWindow* primary, wxEvent& event );
 
-    // Shows string editor dialog. Value to be edited should be read from
-    // value, and if dialog is not cancelled, it should be stored back and true
-    // should be returned if that was the case.
-    virtual bool OnButtonClick( wxPropertyGrid* propgrid, wxString& value );
-
-    static bool DisplayEditorDialog( wxPGProperty* prop,
-                                     wxPropertyGrid* propGrid,
-                                     wxString& value );
+protected:
+    virtual bool DisplayEditorDialog(wxPropertyGrid* pg, wxVariant& value);
 };
 
 
-
-
 /** @class wxDirProperty
     @ingroup classes
-    Like wxLongStringProperty, but the button triggers dir selector instead.
+    Like wxLongStringProperty, but the button triggers directory selector
+    instead.
 
     <b>Supported special attributes:</b>
-    - "DialogMessage": Sets specific message in the dir selector.
+    - ::wxPG_DIALOG_TITLE: Sets a specific title for the file dialog (since 3.1.3).
 */
-class wxDirProperty : public wxLongStringProperty
+class wxDirProperty : public wxEditorDialogProperty
 {
 public:
-    wxDirProperty( const wxString& name = wxPG_LABEL,
-                   const wxString& label = wxPG_LABEL,
+    wxDirProperty( const wxString& label = wxPG_LABEL,
+                   const wxString& name = wxPG_LABEL,
                    const wxString& value = wxEmptyString );
     virtual ~wxDirProperty();
 
-    virtual bool DoSetAttribute( const wxString& name, wxVariant& value );
+    virtual wxString ValueToString(wxVariant& value, int argFlags = 0) const;
+    virtual bool StringToValue(wxVariant& variant, const wxString& text,
+                               int argFlags = 0) const;
     virtual wxValidator* DoGetValidator() const;
 
-    virtual bool OnButtonClick ( wxPropertyGrid* propGrid, wxString& value );
-
 protected:
-    wxString    m_dlgMessage;
+    virtual bool DisplayEditorDialog(wxPropertyGrid* pg, wxVariant& value);
 };
 
 
@@ -636,8 +713,12 @@ protected:
 /** @class wxArrayStringProperty
     @ingroup classes
     Property that manages a list of strings.
+
+    <b>Supported special attributes:</b>
+    - ::wxPG_ARRAY_DELIMITER: Sets string delimiter character.
+    - ::wxPG_DIALOG_TITLE: Sets a specific title for the editor dialog (since 3.1.3).
 */
-class wxArrayStringProperty : public wxPGProperty
+class wxArrayStringProperty : public wxEditorDialogProperty
 {
 public:
     wxArrayStringProperty( const wxString& label = wxPG_LABEL,
@@ -650,26 +731,23 @@ public:
     virtual bool StringToValue( wxVariant& variant,
                                 const wxString& text,
                                 int argFlags = 0 ) const;
-    virtual bool OnEvent( wxPropertyGrid* propgrid,
-                          wxWindow* primary, wxEvent& event );
     virtual bool DoSetAttribute( const wxString& name, wxVariant& value );
 
-    // Implement in derived class for custom array-to-string conversion.
-    virtual void ConvertArrayToString(const wxArrayString& arr,
-                                      wxString* pString,
-                                      const wxUniChar& delimiter) const;
+    /**
+        Implement in derived class for custom array-to-string conversion.
+    */
+    virtual wxString ConvertArrayToString(const wxArrayString& arr,
+                                          const wxUniChar& delimiter) const;
 
-    // Shows string editor dialog. Value to be edited should be read from
-    // value, and if dialog is not cancelled, it should be stored back and true
-    // should be returned if that was the case.
+    /**
+        Shows string editor dialog to edit the individual item. Value to be edited
+        should be read from @a value, and if dialog is not cancelled, it
+        should be stored back and @true should be returned if that was the case.
+    */
     virtual bool OnCustomStringEdit( wxWindow* parent, wxString& value );
 
-    // Helper.
-    virtual bool OnButtonClick( wxPropertyGrid* propgrid,
-                                wxWindow* primary,
-                                const wxChar* cbt );
-
-    // Creates wxPGArrayEditorDialog for string editing. Called in OnButtonClick.
+    /** Creates wxPGArrayEditorDialog for string editing.
+    */
     virtual wxPGArrayEditorDialog* CreateEditorDialog();
 
     enum ConversionFlags
@@ -679,20 +757,24 @@ public:
     };
 
     /**
-        Generates contents for string dst based on the contents of
-        wxArrayString src.
+        Generates string based on the contents of wxArrayString @a src.
     */
-    static void ArrayStringToString( wxString& dst, const wxArrayString& src,
-                                     wxUniChar delimiter, int flags );
+    static wxString ArrayStringToString(const wxArrayString& src,
+                                        wxUniChar delimiter, int flags);
 
 protected:
-    // Previously this was to be implemented in derived class for array-to-
-    // string conversion. Now you should implement ConvertValueToString()
-    // instead.
+    virtual bool DisplayEditorDialog(wxPropertyGrid* pg, wxVariant& value);
+
+    /**
+        Previously this was to be implemented in derived class for array-to-
+        string conversion. Now you should implement ConvertValueToString()
+        instead.
+    */
     virtual void GenerateValueAsString();
 
     wxString        m_display; // Cache for displayed text.
     wxUniChar       m_delimiter;
+    wxString        m_customBtnText;
 };
 
 
@@ -711,13 +793,6 @@ public:
 
     void Init();
 
-    wxPGArrayEditorDialog( wxWindow *parent,
-                         const wxString& message,
-                         const wxString& caption,
-                         long style = wxAEDIALOG_STYLE,
-                         const wxPoint& pos = wxDefaultPosition,
-                         const wxSize& sz = wxDefaultSize );
-
     bool Create( wxWindow *parent,
                  const wxString& message,
                  const wxString& caption,
@@ -726,7 +801,12 @@ public:
                  const wxSize& sz = wxDefaultSize );
 
     void EnableCustomNewAction();
-    
+
+    /** Sets tooltip text for button allowing the user to enter new string.
+        @since 3.1.3
+    */
+    void SetNewButtonText(const wxString& text);
+
     /** Set value modified by dialog.
     */
     virtual void SetDialogValue( const wxVariant& value );
@@ -745,27 +825,25 @@ public:
     */
     virtual wxValidator* GetTextCtrlValidator() const;
 
-    // Returns true if array was actually modified
+    /** Returns true if array was actually modified
+    */
     bool IsModified() const;
 
-    // wxEditableListBox utilities
     int GetSelection() const;
 
 protected:
     wxEditableListBox*  m_elb;
-
-    // These are used for focus repair
     wxWindow*           m_elbSubPanel;
     wxWindow*           m_lastFocused;
 
-    // A new item, edited by user, is pending at this index.
-    // It will be committed once list ctrl item editing is done.
+    /** A new item, edited by user, is pending at this index.
+        It will be committed once list ctrl item editing is done.
+    */
     int             m_itemPendingAtIndex;
 
     bool            m_modified;
     bool            m_hasCustomNewAction;
 
-    // These must be overridden - must return true on success.
     virtual wxString ArrayGet( size_t index ) = 0;
     virtual size_t ArrayGetCount() = 0;
     virtual bool ArrayInsert( const wxString& str, int index ) = 0;
