@@ -9,9 +9,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #if wxUSE_IMAGE && wxUSE_GIF
 
@@ -26,6 +23,7 @@
 #include "wx/gifdecod.h"
 #include "wx/stream.h"
 #include "wx/anidecod.h" // wxImageArray
+#include "wx/scopedarray.h"
 
 #define GIF89_HDR     "GIF89a"
 #define NETSCAPE_LOOP "NETSCAPE2.0"
@@ -68,7 +66,7 @@ struct GifHashTableType
     wxUint32 HTable[HT_SIZE];
 };
 
-IMPLEMENT_DYNAMIC_CLASS(wxGIFHandler,wxImageHandler)
+wxIMPLEMENT_DYNAMIC_CLASS(wxGIFHandler,wxImageHandler);
 
 //----------------------------------------------------------------------------
 // Forward declarations
@@ -116,53 +114,31 @@ static bool wxGIFHandler_BufferedOutput(wxOutputStream *, wxUint8 *buf, int c);
 bool wxGIFHandler::LoadFile(wxImage *image, wxInputStream& stream,
     bool verbose, int index)
 {
-    wxGIFDecoder *decod;
-    wxGIFErrorCode error;
-    bool ok = true;
-
-//    image->Destroy();
-    decod = new wxGIFDecoder();
-    error = decod->LoadGIF(stream);
-
-    if ((error != wxGIF_OK) && (error != wxGIF_TRUNCATED))
+    wxGIFDecoder decod;
+    switch ( decod.LoadGIF(stream) )
     {
-        if (verbose)
-        {
-            switch (error)
-            {
-                case wxGIF_INVFORMAT:
-                    wxLogError(_("GIF: error in GIF image format."));
-                    break;
-                case wxGIF_MEMERR:
-                    wxLogError(_("GIF: not enough memory."));
-                    break;
-                default:
-                    wxLogError(_("GIF: unknown error!!!"));
-                    break;
-            }
-        }
-        delete decod;
-        return false;
+        case wxGIF_OK:
+            break;
+
+        case wxGIF_INVFORMAT:
+            if ( verbose )
+                wxLogError(_("GIF: error in GIF image format."));
+            return false;
+
+        case wxGIF_MEMERR:
+            if ( verbose )
+                wxLogError(_("GIF: not enough memory."));
+            return false;
+
+        case wxGIF_TRUNCATED:
+            if ( verbose )
+                wxLogError(_("GIF: data stream seems to be truncated."));
+
+            // go on; image data is OK
+            break;
     }
 
-    if ((error == wxGIF_TRUNCATED) && verbose)
-    {
-        wxLogError(_("GIF: data stream seems to be truncated."));
-        // go on; image data is OK
-    }
-
-    if (ok)
-    {
-        ok = decod->ConvertToImage(index != -1 ? (size_t)index : 0, image);
-    }
-    else
-    {
-        wxLogError(_("GIF: Invalid gif index."));
-    }
-
-    delete decod;
-
-    return ok;
+    return decod.ConvertToImage(index != -1 ? (size_t)index : 0, image);
 }
 
 bool wxGIFHandler::SaveFile(wxImage *image,
@@ -218,6 +194,8 @@ bool wxGIFHandler::DoSaveFile(const wxImage& image, wxOutputStream *stream,
 
     int width = image.GetWidth();
     int height = image.GetHeight();
+    wxCHECK_MSG( width && height, false, wxS("can't save 0-sized file") );
+
     int width_even = width + ((width % 2) ? 1 : 0);
 
     if (first)
@@ -265,7 +243,7 @@ bool wxGIFHandler::DoSaveFile(const wxImage& image, wxOutputStream *stream,
     }
 
     const wxUint8 *src = image.GetData();
-    wxUint8 *eightBitData = new wxUint8[width];
+    wxScopedArray<wxUint8> eightBitData(width);
 
     SetupCompress(stream, 8);
 
@@ -285,15 +263,13 @@ bool wxGIFHandler::DoSaveFile(const wxImage& image, wxOutputStream *stream,
             src+=3;
         }
 
-        ok = CompressLine(stream, eightBitData, width);
+        ok = CompressLine(stream, eightBitData.get(), width);
         if (!ok)
         {
             break;
         }
     }
 
-    delete [] eightBitData;
-
     wxDELETE(m_hashTable);
 
     return ok;
@@ -415,9 +391,7 @@ bool wxGIFHandler::SetupCompress(wxOutputStream *stream, int bpp)
 bool wxGIFHandler::CompressLine(wxOutputStream *stream,
     const wxUint8 *line, int lineLen)
 {
-    int i = 0, crntCode, newCode;
-    unsigned long newKey;
-    wxUint8 pixel;
+    int i = 0, crntCode;
     if (m_crntCode == FIRST_CODE)                  // It's first time!
         crntCode = line[i++];
     else
@@ -426,10 +400,13 @@ bool wxGIFHandler::CompressLine(wxOutputStream *stream,
     while (i < lineLen)
     {
         // Decode lineLen items.
+        wxUint8 pixel;
         pixel = line[i++];                    // Get next pixel from stream.
         // Form a new unique key to search hash table for the code combines
         // crntCode as Prefix string with Pixel as postfix char.
+        unsigned long newKey;
         newKey = (((unsigned long) crntCode) << 8) + pixel;
+        int newCode;
         if ((newCode = ExistsHashTable(newKey)) >= 0)
         {
             // This Key is already there, or the string is old one, so
