@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     31.05.03
-// Copyright:   (c) 2003 Vadim Zeitlin <vadim@wxwindows.org>
+// Copyright:   (c) 2003 Vadim Zeitlin <vadim@wxwidgets.org>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -19,9 +19,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #if wxUSE_LISTBOX
 
@@ -41,7 +38,7 @@
 // event tables
 // ----------------------------------------------------------------------------
 
-BEGIN_EVENT_TABLE(wxVListBox, wxVScrolledWindow)
+wxBEGIN_EVENT_TABLE(wxVListBox, wxVScrolledWindow)
     EVT_PAINT(wxVListBox::OnPaint)
 
     EVT_KEY_DOWN(wxVListBox::OnKeyDown)
@@ -52,13 +49,13 @@ BEGIN_EVENT_TABLE(wxVListBox, wxVScrolledWindow)
     EVT_KILL_FOCUS(wxVListBox::OnSetOrKillFocus)
 
     EVT_SIZE(wxVListBox::OnSize)
-END_EVENT_TABLE()
+wxEND_EVENT_TABLE()
 
 // ============================================================================
 // implementation
 // ============================================================================
 
-IMPLEMENT_ABSTRACT_CLASS(wxVListBox, wxVScrolledWindow)
+wxIMPLEMENT_ABSTRACT_CLASS(wxVListBox, wxVScrolledWindow);
 const char wxVListBoxNameStr[] = "wxVListBox";
 
 // ----------------------------------------------------------------------------
@@ -79,11 +76,6 @@ bool wxVListBox::Create(wxWindow *parent,
                         long style,
                         const wxString& name)
 {
-#ifdef __WXMSW__
-    if ( (style & wxBORDER_MASK) == wxDEFAULT )
-        style |= wxBORDER_THEME;
-#endif
-
     style |= wxWANTS_CHARS | wxFULL_REPAINT_ON_RESIZE;
     if ( !wxVScrolledWindow::Create(parent, id, pos, size, style, name) )
         return false;
@@ -100,7 +92,7 @@ bool wxVListBox::Create(wxWindow *parent,
     m_colBgSel = wxNullColour;
 
     // flicker-free drawing requires this
-    SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+    SetBackgroundStyle(wxBG_STYLE_PAINT);
 
     return true;
 }
@@ -664,6 +656,7 @@ void wxVListBox::OnKeyDown(wxKeyEvent& event)
             // events for the tabs on MSW
             HandleAsNavigationKey(event);
             // fall through to default
+            wxFALLTHROUGH;
 #endif
         default:
             event.Skip();
@@ -696,13 +689,7 @@ void wxVListBox::OnLeftDown(wxMouseEvent& event)
         if ( event.ShiftDown() )
            flags |= ItemClick_Shift;
 
-        // under Mac Apple-click is used in the same way as Ctrl-click
-        // elsewhere
-#ifdef __WXMAC__
-        if ( event.MetaDown() )
-#else
         if ( event.ControlDown() )
-#endif
             flags |= ItemClick_Ctrl;
 
         DoHandleItemClick(item, flags);
