@@ -42,7 +42,7 @@
 
 // defined in common/init.cpp
 extern int wxEntryReal(int& argc, wxChar **argv);
-extern int wxEntryCleanupReal(int& argc, wxChar **argv);
+extern void wxEntryCleanupReal();
 
 // ============================================================================
 // implementation: various entry points
@@ -192,6 +192,18 @@ int wxEntry(int& argc, wxChar **argv)
 // Windows-specific wxEntry
 // ----------------------------------------------------------------------------
 
+// Declare the functions used in wxCore to access the command line arguments
+// data in wxBase.
+WXDLLIMPEXP_BASE void wxMSWCommandLineInit();
+WXDLLIMPEXP_BASE void wxMSWCommandLineCleanup();
+WXDLLIMPEXP_BASE int& wxMSWCommandLineGetArgc();
+WXDLLIMPEXP_BASE wchar_t** wxMSWCommandLineGetArgv();
+
+#if wxUSE_BASE
+
+namespace
+{
+
 struct wxMSWCommandLineArguments
 {
     wxMSWCommandLineArguments() { argc = 0; argv = NULL; }
@@ -207,10 +219,18 @@ struct wxMSWCommandLineArguments
         argv = ::CommandLineToArgvW(::GetCommandLineW(), &argc);
     }
 
-    ~wxMSWCommandLineArguments()
+    void Cleanup()
     {
         if ( argc )
+        {
             ::LocalFree(argv);
+            argc = 0;
+        }
+    }
+
+    ~wxMSWCommandLineArguments()
+    {
+        Cleanup();
     }
 #else // !wxUSE_UNICODE
     void Init()
@@ -253,10 +273,36 @@ struct wxMSWCommandLineArguments
 
     int argc;
     wxChar **argv;
+
+    wxDECLARE_NO_COPY_CLASS(wxMSWCommandLineArguments);
 };
 
 static wxMSWCommandLineArguments wxArgs;
 
+} // anonymous namespace
+
+WXDLLIMPEXP_BASE void wxMSWCommandLineInit()
+{
+    wxArgs.Init();
+}
+
+WXDLLIMPEXP_BASE void wxMSWCommandLineCleanup()
+{
+    wxArgs.Cleanup();
+}
+
+WXDLLIMPEXP_BASE int& wxMSWCommandLineGetArgc()
+{
+    return wxArgs.argc;
+}
+
+WXDLLIMPEXP_BASE wchar_t** wxMSWCommandLineGetArgv()
+{
+    return wxArgs.argv;
+}
+
+#endif // wxUSE_BASE
+
 #if wxUSE_GUI
 
 // common part of wxMSW-specific wxEntryStart() and wxEntry() overloads
@@ -267,9 +313,11 @@ wxMSWEntryCommon(HINSTANCE hInstance, int nCmdShow)
     wxSetInstance(hInstance);
 #ifdef __WXMSW__
     wxApp::m_nCmdShow = nCmdShow;
+#else
+    wxUnusedVar(nCmdShow);
 #endif
 
-    wxArgs.Init();
+    wxMSWCommandLineInit();
 
     return true;
 }
@@ -282,7 +330,7 @@ WXDLLEXPORT bool wxEntryStart(HINSTANCE hInstance,
     if ( !wxMSWEntryCommon(hInstance, nCmdShow) )
        return false;
 
-    return wxEntryStart(wxArgs.argc, wxArgs.argv);
+    return wxEntryStart(wxMSWCommandLineGetArgc(), wxMSWCommandLineGetArgv());
 }
 
 WXDLLEXPORT int wxEntry(HINSTANCE hInstance,
@@ -293,7 +341,7 @@ WXDLLEXPORT int wxEntry(HINSTANCE hInstance,
     if ( !wxMSWEntryCommon(hInstance, nCmdShow) )
         return -1;
 
-    return wxEntry(wxArgs.argc, wxArgs.argv);
+    return wxEntry(wxMSWCommandLineGetArgc(), wxMSWCommandLineGetArgv());
 }
 
 #endif // wxUSE_GUI
@@ -306,9 +354,16 @@ WXDLLEXPORT int wxEntry(HINSTANCE hInstance,
 
 int wxEntry()
 {
-    wxArgs.Init();
+    wxMSWCommandLineInit();
 
-    return wxEntry(wxArgs.argc, wxArgs.argv);
+    return wxEntry(wxMSWCommandLineGetArgc(), wxMSWCommandLineGetArgv());
+}
+
+void wxEntryCleanup()
+{
+    wxEntryCleanupReal();
+
+    wxMSWCommandLineCleanup();
 }
 
 HINSTANCE wxhInstance = 0;
