@@ -498,7 +498,7 @@ void wxStaticBox::PaintForeground(wxDC& dc, const RECT&)
 
 #if wxUSE_UXTHEME
     // when using XP themes, neither setting the text colour nor transparent
-    // background mode doesn't change anything: the static box def window proc
+    // background mode changes anything: the static box def window proc
     // still draws the label in its own colours, so we need to redraw the text
     // ourselves if we have a non default fg colour
     if ( m_hasFgCol && wxUxThemeIsActive() && !m_labelWin )
@@ -636,10 +636,10 @@ void wxStaticBox::OnPaint(wxPaintEvent& WXUNUSED(event))
                 labelRect.GetLeft() - gap - border,
                 borderTop,
                 &memdc, border, 0);
-        dc.Blit(labelRect.GetRight() + gap, 0,
-                rc.right - (labelRect.GetRight() + gap),
-                borderTop,
-                &memdc, border, 0);
+
+        const int xStart = labelRect.GetRight() + gap;
+        dc.Blit(xStart, 0, rc.right - xStart, borderTop,
+                &memdc, xStart, 0);
     }
     else
     {
