@@ -4,11 +4,12 @@
 # Author:      Andrea Gavana
 #
 # Created:     30-Nov-2010
-# Copyright:   (c) 2010-2018 by Total Control Software
+# Copyright:   (c) 2010-2020 by Total Control Software
 # License:     wxWindows License
 #---------------------------------------------------------------------------
 
 # Standard library imports
+import sys
 import os
 import re
 import glob
@@ -24,6 +25,9 @@ from .constants import HTML_REPLACE, TODAY, SPHINXROOT, SECTIONS_EXCLUDE
 from .constants import CONSTANT_INSTANCES, WIDGETS_IMAGES_ROOT, SPHINX_IMAGES_ROOT
 from .constants import DOCSTRING_KEY
 
+PY2 = sys.version_info[0] == 2
+PY3 = sys.version_info[0] == 3
+
 # ----------------------------------------------------------------------- #
 
 
@@ -56,6 +60,9 @@ def makeHeadings():
         rel_path = os.path.normpath(rel_path).replace('\\', '/')
         text += templates.TEMPLATE_HEADINGS % (name, rel_path, width)
 
+    # Add custom roles
+    text += "\n.. role:: html(raw)\n    :format: html\n\n"
+
     writeIfChanged(heading_file, text)
 
 # ----------------------------------------------------------------------- #
@@ -68,7 +75,7 @@ def genIndexes(sphinxDir):
     main class index and some clean-up/maintenance of the generated ReST
     files.
     """
-
+    print("Generating indexes...")
     pklfiles = glob.glob(sphinxDir + '/*.pkl')
 
     for file in pklfiles:
@@ -115,9 +122,8 @@ def buildEnumsAndMethods(sphinxDir):
 
     for input in textfiles:
 
-        fid = textfile_open(input, 'rt')
-        orig_text = text = fid.read()
-        fid.close()
+        with textfile_open(input, 'rt') as fid:
+            orig_text = text = fid.read()
 
         for old, new in list(enum_dict.items()):
             text = text.replace(old, new)
@@ -184,9 +190,8 @@ def buildEnumsAndMethods(sphinxDir):
         text = addSpacesToLinks(text)
 
         if text != orig_text:
-            fid = textfile_open(input, 'wt')
-            fid.write(text)
-            fid.close()
+            with textfile_open(input, 'wt') as fid:
+                fid.write(text)
 
     if not unreferenced_classes:
         return
@@ -200,22 +205,20 @@ def buildEnumsAndMethods(sphinxDir):
            'the text file "unreferenced_classes.inc" together with the ReST file names where they\n' \
            'appear.\n\n'
 
-    keys = list(unreferenced_classes.keys())
-    keys.sort()
 
-    fid = textfile_open(os.path.join(SPHINXROOT, 'unreferenced_classes.inc'), 'wt')
-    fid.write('\n')
-    fid.write('='*50 + ' ' + '='*50 + '\n')
-    fid.write('%-50s %-50s\n'%('Reference', 'File Name(s)'))
-    fid.write('='*50 + ' ' + '='*50 + '\n')
+    with textfile_open(os.path.join(SPHINXROOT, 'unreferenced_classes.inc'), 'wt') as fid:
+        fid.write('\n')
+        fid.write('='*50 + ' ' + '='*50 + '\n')
+        fid.write('%-50s %-50s\n'%('Reference', 'File Name(s)'))
+        fid.write('='*50 + ' ' + '='*50 + '\n')
 
-    for key in keys:
-        fid.write('%-50s %-50s\n'%(key, ', '.join(unreferenced_classes[key])))
+        for key in sorted(unreferenced_classes):
+            fid.write('%-50s %-50s\n'%(key, ', '.join(unreferenced_classes[key])))
 
-    fid.write('='*50 + ' ' + '='*50 + '\n')
-    fid.close()
+        fid.write('='*50 + ' ' + '='*50 + '\n')
 
-    print((warn%(len(keys))))
+
+    print((warn%(len(unreferenced_classes))))
 
 
 # ----------------------------------------------------------------------- #
@@ -254,13 +257,6 @@ def findInherited(input, class_summary, enum_base, text):
             text = text.replace(regs, newtext, 1)
             continue
 
-
-##        elif meth_name in enum_base:
-##            newtext = ':ref:`%s`'%meth_name
-##            text = text.replace(regs, newtext, 1)
-##            continue
-
-
         if meth_name in CONSTANT_INSTANCES:
             text = text.replace(regs, '``%s``'%meth_name, 1)
             continue
@@ -372,9 +368,7 @@ def reformatFunctions(file):
     else:
         label = '.'.join(local_file.split('.')[0:2])
 
-    names = list(functions.keys())
-    names = [name.lower() for name in names]
-    names.sort()
+    names = sorted([name.lower() for name in functions])
 
     text = templates.TEMPLATE_FUNCTION_SUMMARY % (label, label)
 
@@ -387,8 +381,7 @@ def reformatFunctions(file):
     text += '  |  '.join([':ref:`%s <%s %s>`'%(letter, label, letter) for letter in letters])
     text += '\n\n\n'
 
-    names = list(functions.keys())
-    names = sorted(names, key=str.lower)
+    names = sorted(functions, key=str.lower)
     imm = ItemModuleMap()
 
     for letter in letters:
@@ -443,13 +436,10 @@ def makeModuleIndex(sphinxDir, file):
     enum_base = [os.path.split(os.path.splitext(enum)[0])[1] for enum in enum_files]
 
     imm = ItemModuleMap()
-    names = list(classes.keys())
-    names.sort(key=lambda n: imm.get_fullname(n))
+    names = sorted(classes, key=lambda n: imm.get_fullname(n))
 
     # Workaround to sort names in a case-insensitive way
-    lower_to_name = {}
-    for name in names:
-        lower_to_name[name.lower()] = name
+    lower_to_name = {name.lower(): name for name in names}
 
     text = ''
     if module:
@@ -461,8 +451,7 @@ def makeModuleIndex(sphinxDir, file):
     text += '%-80s **Short Description**\n' % '**Class**'
     text += 80*'=' + ' ' + 80*'=' + '\n'
 
-    lower_names = list(lower_to_name.keys())
-    lower_names.sort()
+    lower_names = sorted(lower_to_name)
 
     for lower in lower_names:
         cls = lower_to_name[lower]
@@ -488,8 +477,7 @@ def makeModuleIndex(sphinxDir, file):
     functionsFile = os.path.join(sphinxDir, module + '.functions.pkl')
     if os.path.exists(functionsFile):
         pf = PickleFile(functionsFile)
-        functions = list(pf.read().keys())
-        functions.sort(key=lambda n: imm.get_fullname(n))
+        functions = sorted(pf.read(), key=lambda n: imm.get_fullname(n))
 
         pf = PickleFile(os.path.join(SPHINXROOT, 'function_summary.pkl'))
         function_summaries = pf.read()
@@ -519,6 +507,7 @@ def makeModuleIndex(sphinxDir, file):
 # ----------------------------------------------------------------------- #
 
 def genGallery():
+    print("Generating gallery...")
 
     link = '<div class="gallery_class">'
 
@@ -554,8 +543,7 @@ def genGallery():
         possible = simple.lower()
         html_files[possible + '.png'] = simple + '.html'
 
-    keys = list(html_files.keys())
-    keys.sort()
+    keys = sorted(html_files)
 
     text = ''
 
@@ -659,7 +647,6 @@ def addJavaScript(text):
 # ----------------------------------------------------------------------- #
 
 def postProcess(folder, options):
-
     fileNames = glob.glob(folder + "/*.html")
 
     enum_files = glob.glob(folder + '/*.enumeration.html')
@@ -676,60 +663,44 @@ def postProcess(folder, options):
         new = '(<a class="reference internal" href="%s" title="%s"><em>%s</em></a>)'%(html_file, base, base)
         enum_dict['(<em>%s</em>)'%enum] = new
 
-    for files in fileNames:
-
-        if "genindex" in files or "modindex" in files:
+    for filename in fileNames:
+        if "genindex" in filename or "modindex" in filename:
             continue
 
         methods_done = properties_done = False
 
-        fid = open(files, "rt")
-        orig_text = text = fid.read()
-        fid.close()
-
-        split = os.path.split(files)[1]
-
-        if split == 'index.html':
-            text = changeWelcomeText(text, options)
-        else:
-            text = text.replace('class="headerimage"', 'class="headerimage-noshow"')
-
-        text = text.replace('&#8211; <p>', '&#8211; ')
-        text = text.replace('<p><img alt="overload"', '<br><p><img alt="overload"')
-        text = text.replace('<strong>Overloaded Implementations</strong>', '<em><strong>Overloaded Implementations</strong></em>')
-        text = text.replace('<strong>~~~</strong></p>', '<hr style="color:#0000FF;background-color:#0000FF;height:1px;border:none;width:50%;float:left" /></p><br>')
-
-        text = text.replace('<p><img alt="contributed"', '<br><p><img alt="contributed"')
+        with textfile_open(filename, "rt") as fid:
+            orig_text = text = fid.read()
 
+        text = text.replace('Overloaded Implementations:', '<strong>Overloaded Implementations:</strong>')
         for item in HTML_REPLACE:
-            text = text.replace('<dl class="%s">'%item, '<br><hr />\n<dl class="%s">'%item)
+            if item != 'class':
+                text = text.replace('<dl class="%s">'%item, '\n<br><hr />\n<dl class="%s">'%item)
 
         newtext = ''
         splitted_text = text.splitlines()
         len_split = len(splitted_text)
 
         for index, line in enumerate(splitted_text):
-            if '<div class="admonition-availability admonition' in line:
-                line = '<div class="admonition-availability admonition availability">'
-
             if index < len_split - 1:
+                if '– <p>' in line and '</p>' in line:
+                    line = line.replace('– <p>', '– ')
+                    line = line.replace('</p>', '')
 
                 if line.strip() == '<br><hr />' or line.strip() == '<dd><br><hr />':
                     next_line = splitted_text[index+1]
                     stripline = next_line.strip()
 
+                    # replace the <hr> with a new headline for the first method or first property
                     if (stripline == '<dl class="staticmethod">' or stripline == '<dl class="method">' \
                        or stripline == '<dl class="classmethod">') and not methods_done:
-                        line = '<br><h3>Methods<a class="headerlink" href="#methods" title="Permalink to this headline">¶</a></h3>' + '\n' + line
+                        line = '\n<br><h3>Methods<a class="headerlink" href="#methods" title="Permalink to this headline">¶</a></h3>\n'
                         methods_done = True
 
                     elif stripline == '<dl class="attribute">' and not properties_done:
-                        line = '<br><h3>Properties<a class="headerlink" href="#properties" title="Permalink to this headline">¶</a></h3>' + '\n' + line
+                        line = '\n<br><h3>Properties<a class="headerlink" href="#properties" title="Permalink to this headline">¶</a></h3>\n'
                         properties_done = True
 
-            if '<em>  ' in line and '&#8211;' in line:
-                line = line.replace('<em>  ', '<em>')
-
             newtext += line + '\n'
 
         for old, new in list(enum_dict.items()):
@@ -737,10 +708,17 @@ def postProcess(folder, options):
 
         newtext = addJavaScript(newtext)
 
+        basename = os.path.split(filename)[1]
+        if basename == 'index.html':
+            newtext = changeWelcomeText(newtext, options)
+        else:
+            newtext = removeHeaderImage(newtext, options)
+        if '1moduleindex' in basename:
+            newtext = tweakModuleIndex(newtext)
+
         if orig_text != newtext:
-            fid = open(files, "wt")
-            fid.write(newtext)
-            fid.close()
+            with textfile_open(filename, "wt") as fid:
+                fid.write(newtext)
 
 
 # ----------------------------------------------------------------------- #
@@ -766,6 +744,25 @@ def changeWelcomeText(text, options):
     return text
 
 
+def removeHeaderImage(text, options):
+    from bs4 import BeautifulSoup
+    soup = BeautifulSoup(text, 'html.parser')
+    tag = soup.find('div', 'headerimage')
+    if tag:
+        tag.extract()
+        text = unicode(soup) if PY2 else str(soup)
+    return text
+
+
+def tweakModuleIndex(text):
+    from bs4 import BeautifulSoup
+    soup = BeautifulSoup(text, 'html.parser')
+    for tag in soup.findAll('a'):
+        # Chop off the #anchor if it is identical to the basname of the doc
+        href = tag['href'].split('.html#')
+        if len(href) == 2 and href[0] == href[1]:
+            tag['href'] = href[0] + '.html'
+    return unicode(soup) if PY2 else str(soup)
 
 
 def tooltipsOnInheritance(text, class_summary):
