@@ -5,7 +5,7 @@
 # Author:      Andrea Gavana
 #
 # Created:     30-Nov-2010
-# Copyright:   (c) 2010-2018 by Total Control Software
+# Copyright:   (c) 2010-2020 by Total Control Software
 # License:     wxWindows License
 #---------------------------------------------------------------------------
 
@@ -92,7 +92,7 @@ class ODict(UserDict):
 
     def update(self, dict):
         UserDict.update(self, dict)
-        for key in list(dict.keys()):
+        for key in dict:
             if key not in self._keys: self._keys.append(key)
 
     def values(self):
@@ -561,7 +561,7 @@ header = """\
    This file was generated by Phoenix's sphinx generator and associated
    tools, do not edit by hand.
 
-   Copyright: (c) 2011-2018 by Total Control Software
+   Copyright: (c) 2011-2020 by Total Control Software
    License:   wxWindows License
 
 """
@@ -861,3 +861,17 @@ def isPython3():
 
     return sys.version_info >= (3, )
 
+
+def textfile_open(filename, mode='rt'):
+    """
+    Simple wrapper around open() that will use codecs.open on Python2 and
+    on Python3 will add the encoding parameter to the normal open(). The
+    mode parameter must include the 't' to put the stream into text mode.
+    """
+    assert 't' in mode
+    if sys.version_info < (3,):
+        import codecs
+        mode = mode.replace('t', '')
+        return codecs.open(filename, mode, encoding='utf-8')
+    else:
+        return open(filename, mode, encoding='utf-8')
