@@ -612,7 +612,7 @@ class AuiDefaultDockArt(object):
         draw_text = ChopText(dc, text, variable)
 
         if captionLeft:
-            dc.DrawRotatedText(draw_text, rect.x+(rect.width/2)-(h/2)-1, rect.y+rect.height-3-caption_offset, 90)
+            dc.DrawRotatedText(draw_text, rect.x+(rect.width//2)-(h//2)-1, rect.y+rect.height-3-caption_offset, 90)
         else:
             dc.DrawText(draw_text, rect.x+3+caption_offset, rect.y+(rect.height//2)-(h//2)-1)
 
