@@ -112,7 +112,7 @@ def _FontFaceFromFont(font):
 
     elif 'wxMSW' in wx.PlatformInfo:
         fontfaceptr = voidp( cairoLib.cairo_win32_font_face_create_for_hfont(
-            ctypes.c_ulong(font.GetHFONT())) )
+            ctypes.c_ulong(int(font.GetHFONT()))) )
         fontface = pycairoAPI.FontFace_FromFontFace(fontfaceptr)
 
     elif 'wxGTK' in wx.PlatformInfo:
